@@ -25,6 +25,8 @@ struct Configuration::Private {
     std::vector<CategoryColor> categoryColor;
     Dictionary dictionary;
     SnippetsCollection snippets;
+    Relation relation;
+    FileDriver fileDriver;
     ConfigurationType type;
     std::string uid;
     cDateTime created;
@@ -57,6 +59,20 @@ Configuration::Configuration(const SnippetsCollection &snippets)
     d->type = TypeSnippet;
 }
 
+Configuration::Configuration(const Relation &relation)
+:   d(new Configuration::Private)
+{
+    d->relation = relation;
+    d->type = TypeRelation;
+}
+
+Configuration::Configuration(const FileDriver &fileDriver)
+:   d(new Configuration::Private)
+{
+    d->fileDriver = fileDriver;
+    d->type = TypeFileDriver;
+}
+
 Configuration::Configuration(const Configuration &other)
 :   d(new Configuration::Private)
 {
@@ -129,4 +145,14 @@ SnippetsCollection Configuration::snippets() const
     return d->snippets;
 }
 
+Relation Configuration::relation() const
+{
+    return d->relation;
+}
+
+FileDriver Configuration::fileDriver() const
+{
+    return d->fileDriver;
+}
+
 } //Namespace
