@@ -1353,7 +1353,9 @@ void setAlarms(typename KolabType::components_type& components, const IncidenceT
             case Kolab::Alarm::AudioAlarm:
                 p = std::auto_ptr<PropType>(new PropType(PropType::action_type(AUDIOALARM), trigger));
                 p->description(PropType::description_type(alarm.description()));
-                p->attach(fromAttachment(alarm.audioFile()));
+                if (alarm.audioFile().isValid()) {
+                    p->attach(fromAttachment(alarm.audioFile()));
+                }
                 break;
             default:
                 ERROR("invalid alarm");
@@ -1401,16 +1403,17 @@ void getAlarms(IncidenceType &incidence, const typename KolabType::components_ty
             }
             alarm = Kolab::Alarm((*prop.summary()).text(), (*prop.description()).text(), attendees);
         } else if (prop.action().text() == AUDIOALARM) {
-            if (!prop.attach()) {
-                ERROR("audio file is missing");
-                continue;
+            if (prop.attach()) {
+                const Kolab::Attachment &attach = toAttachment<icalendar_2_0::properties::attach_type>(*prop.attach());
+                if (!attach.isValid()) {
+                    ERROR("audio file is invalid");
+                    continue;
+                }
+                alarm = Kolab::Alarm(attach);
+            } else {
+                //An audio alarm without an audio file is valid according to spec
+                alarm = Kolab::Alarm(Kolab::Alarm::AudioAlarm);
             }
-            const Kolab::Attachment &attach = toAttachment<icalendar_2_0::properties::attach_type>(*prop.attach());
-            if (!attach.isValid()) {
-                ERROR("audio file is invalid");
-                continue;
-            }
-            alarm = Kolab::Alarm(attach);
         } else {
             ERROR("unknown alarm type " + prop.action().text());
             continue;
