@@ -34,6 +34,7 @@ void ValidationTest::testErrorOnEmptyEvent()
 void ValidationTest::testNoErrorOnValidEvent()
 {
     Event event;
+    event.setCreated(Kolab::cDateTime(2006,1,6,12,0,0,true)); //UTC
     event.setStart(cDateTime(2013,1,1,1,1,1));
     writeEvent(event);
     QCOMPARE(Kolab::error(), Kolab::NoError);
@@ -43,18 +44,21 @@ void ValidationTest::testNoErrorOnValidTodo()
 {
     {
         Todo todo;
+        todo.setCreated(Kolab::cDateTime(2006,1,6,12,0,0,true)); //UTC
         todo.setStart(cDateTime("Europe/Zurich", 2013,1,1,1,1,1));
         writeTodo(todo);
         QCOMPARE(Kolab::error(), Kolab::NoError);
     }
     {
         Todo todo;
+        todo.setCreated(Kolab::cDateTime(2006,1,6,12,0,0,true)); //UTC
         todo.setDue(cDateTime("Europe/Zurich", 2013,1,1,1,1,1));
         writeTodo(todo);
         QCOMPARE(Kolab::error(), Kolab::NoError);
     }
     {
         Todo todo;
+        todo.setCreated(Kolab::cDateTime(2006,1,6,12,0,0,true)); //UTC
         todo.setStart(cDateTime("Europe/Zurich", 2013,1,1,1,1,1));
         todo.setDue(cDateTime("Europe/Zurich", 2013,1,1,1,1,1));
         writeTodo(todo);
@@ -65,6 +69,7 @@ void ValidationTest::testNoErrorOnValidTodo()
 void ValidationTest::testOlsonTimezone()
 {
     Event event;
+    event.setCreated(Kolab::cDateTime(2006,1,6,12,0,0,true)); //UTC
     event.setStart(cDateTime("Europe/Zurich",2013,1,1,1,1,1));
     writeEvent(event);
     QCOMPARE(Kolab::error(), Kolab::NoError);
@@ -73,12 +78,14 @@ void ValidationTest::testOlsonTimezone()
 void ValidationTest::testDifferentTimezones()
 {
     Event event;
+    event.setCreated(Kolab::cDateTime(2006,1,6,12,0,0,true)); //UTC
     event.setStart(cDateTime("Europe/Zurich",2013,1,1,1,1,1));
     event.setEnd(cDateTime("Europe/London",2013,1,1,1,1,1));
     writeEvent(event);
     QCOMPARE(Kolab::error(), Kolab::NoError);
 
     Todo todo;
+    todo.setCreated(Kolab::cDateTime(2006,1,6,12,0,0,true)); //UTC
     todo.setStart(cDateTime("Europe/Zurich",2013,1,1,1,1,1));
     todo.setDue(cDateTime("Europe/London",2013,1,1,1,1,1));
     writeTodo(todo);
@@ -88,6 +95,7 @@ void ValidationTest::testDifferentTimezones()
 void ValidationTest::testUTCwithTimezone()
 {
     Event event;
+    event.setCreated(Kolab::cDateTime(2006,1,6,12,0,0,true)); //UTC
     cDateTime dt("Europe/Zurich",2013,1,1,1,1,1);
     dt.setUTC(true);
     event.setStart(dt);
@@ -98,6 +106,7 @@ void ValidationTest::testUTCwithTimezone()
 void ValidationTest::testTimezoneZ()
 {
     Event event;
+    event.setCreated(Kolab::cDateTime(2006,1,6,12,0,0,true)); //UTC
     event.setStart(cDateTime("Z",2013,1,1,1,1,1));
     writeEvent(event);
     QCOMPARE(Kolab::error(), Kolab::Error);
@@ -106,6 +115,7 @@ void ValidationTest::testTimezoneZ()
 void ValidationTest::testWindowsTimezone()
 {
     Event event;
+    event.setCreated(Kolab::cDateTime(2006,1,6,12,0,0,true)); //UTC
     event.setStart(cDateTime("Central European Standard Time",2013,1,1,1,1,1));
     writeEvent(event);
     QCOMPARE(Kolab::error(), Kolab::Error);
